@@ -3,11 +3,14 @@
 Start the celery clock service from the Django management command.
 
 """
+from __future__ import absolute_import
+
 from celery.bin import celerybeat
 
+from djcelery.app import app
 from djcelery.management.base import CeleryCommand
 
-beat = celerybeat.BeatCommand()
+beat = celerybeat.BeatCommand(app=app)
 
 
 class Command(CeleryCommand):
