@@ -1,19 +1,24 @@
 """
 
-Curses Celery Event Viewer.
+Shortcut to the Django snapshot service.
 
 """
-from celery.bin.celeryev import run_celeryev, OPTION_LIST
+from __future__ import absolute_import
 
+from celery.bin import celeryev
+
+from djcelery.app import app
 from djcelery.management.base import CeleryCommand
 
+ev = celeryev.EvCommand(app=app)
+
 
 class Command(CeleryCommand):
     """Run the celery curses event viewer."""
-    option_list = CeleryCommand.option_list + OPTION_LIST
+    option_list = CeleryCommand.option_list + ev.get_options()
     help = 'Takes snapshots of the clusters state to the database.'
 
     def handle(self, *args, **options):
         """Handle the management command."""
         options["camera"] = "djcelery.snapshot.Camera"
-        run_celeryev(*args, **options)
+        ev.run(*args, **options)
