@@ -3,11 +3,14 @@
 Start the celery daemon from the Django management command.
 
 """
+from __future__ import absolute_import
+
 from celery.bin import celeryd
 
+from djcelery.app import app
 from djcelery.management.base import CeleryCommand
 
-worker = celeryd.WorkerCommand()
+worker = celeryd.WorkerCommand(app=app)
 
 
 class Command(CeleryCommand):
